"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const directives_1 = require("./directives");
function fieldAlreadyExists(fieldsArr, otherField) {
    const result = fieldsArr.find(field => field.name.value === otherField.name.value);
    if (result) {
        const t1 = utils_1.extractType(result.type);
        const t2 = utils_1.extractType(otherField.type);
        if (t1.name.value !== t2.name.value) {
            throw new Error(`Field "${otherField.name.value}" already defined with a different type. Declared as "${t1.name.value}", but you tried to override with "${t2.name.value}"`);
        }
    }
    return !!result;
}
function mergeFields(f1, f2) {
    const result = [...f2];
    for (const field of f1) {
        if (fieldAlreadyExists(result, field)) {
            const existing = result.find((f) => f.name.value === field.name.value);
            existing['directives'] = directives_1.mergeDirectives(field['directives'], existing['directives']);
        }
        else {
            result.push(field);
        }
    }
    return result;
}
exports.mergeFields = mergeFields;
//# sourceMappingURL=fields.js.map