import { buildASTSchema } from "graphql";
export function extractFieldResolversFromObjectType(objectType, options) {
    const fieldResolvers = {};
    const fieldMap = objectType.getFields();
    let selectedFieldNames;
    if (options && options.selectedTypeDefs) {
        const invalidSchema = buildASTSchema(options.selectedTypeDefs);
        const typeMap = invalidSchema.getTypeMap();
        if (!(objectType.name in typeMap)) {
            return {};
        }
        else {
            const selectedObjectType = typeMap[objectType.name];
            selectedFieldNames = Object.keys(selectedObjectType.getFields());
        }
    }
    for (const fieldName in fieldMap) {
        if (selectedFieldNames && !selectedFieldNames.includes(fieldName)) {
            continue;
        }
        const fieldDefinition = fieldMap[fieldName];
        if ('subscribe' in fieldDefinition) {
            fieldResolvers[fieldName] = {
                subscribe: fieldDefinition.subscribe,
            };
        }
        else if ('resolve' in fieldDefinition) {
            fieldResolvers[fieldName] = fieldDefinition.resolve;
        }
    }
    return fieldResolvers;
}
//# sourceMappingURL=extract-field-resolvers-from-object-type.js.map